#!/usr/bin/env python

class DiscUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'UsedSize': 'long',
            'TotalSize': 'long'

        }

        self.attributeMap = {
            'UsedSize': 'UsedSize','TotalSize': 'TotalSize'}       

        self.UsedSize = None # long
        self.TotalSize = None # long
        
