__author__ = 'imranwar'

from setuptools import setup, find_packages

setup(
    name = 'asposestorage',
    packages = find_packages(),
    version = '1.0.2',
    description = 'Aspose Cloud SDK for Python allows you to use Aspose API in your Python applications',
    author='Imran Anwar',
    author_email='imranwar@gmail.com',
    url='http://www.aspose.com',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ]
)
